/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.task.model;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.openide.filesystems.FileObject;
import org.openide.util.Exceptions;
import org.openide.util.lookup.ServiceProvider;

/**
 * Manages saving and loading of Tasks (tsk)
 * @author Gerben Feenstra
 */
@ServiceProvider(service = TaskManager.class)
public class TaskManagerImpl implements TaskManager{

    private static final Logger LOGGER  = Logger.getLogger("nl.cloudfarming.client.task.model.TaskManagerImpl");

    /**
     * Load a Task from a file object
     *
     * @param fileObject
     * @return
     */
    @Override
    public Task load(FileObject fileObject) {
        LOGGER.log(Level.FINEST, "loading Task object from file {0}", fileObject.getName());
        Task task = null;
        try (ObjectInputStream ois = new ObjectInputStream(fileObject.getInputStream())) {
            task = (Task) ois.readObject();
        } catch (ClassNotFoundException | IOException ex) {
            Exceptions.printStackTrace(ex);
        }
        return task;
    }

    /**
     *
     * @param task
     * @param fileObject
     */
    @Override
    public void save(Task task, FileObject fileObject) {
        LOGGER.log(Level.FINEST, "Saving task object to file {0}", fileObject.getName());
        assert (Task.EXT.equals(fileObject.getExt())):"Task FileObjects should always have the task extention (" + Task.EXT + ")";
        try (ObjectOutputStream oos = new ObjectOutputStream(fileObject.getOutputStream())) {
            oos.writeObject(task);
        } catch (IOException ex) {
            Exceptions.printStackTrace(ex);
        }
    }
}
