/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.task.model;

import com.vividsolutions.jts.geom.Geometry;
import com.vividsolutions.jts.geom.Point;
import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.Objects;
import nl.cloudfarming.client.geometry.model.Shape;
import nl.cloudfarming.client.geoviewer.Geometrical;

/**
 * A treatment zone is a geographical area which is treated in a particular way.
 * @author Merijn Zengers
 */
public class TreatmentZone extends Shape implements Geometrical<Geometry> {
    
    private String value;  
    private Geometry geometry;
    public static final String PROP_GEOMETRY = "geometry";
    private transient PropertyChangeSupport propertyChangeSupport = new PropertyChangeSupport(this);
    
    public String getValue() {
        return value;
    }

    public void setValue(String value) {
        this.value = value;
    }
 
    /**
     * Get the value of geometry
     *
     * @return the value of geometry
     */
    @Override
    public Geometry getGeometry() {
        return geometry;
    }

    @Override
    public Point getCentroid() {
        return geometry.getCentroid();
    }
        
    /**
     * Set the value of geometry
     *
     * @param geometry new value of geometry
     */
    public void setGeometry(Geometry geometry) {
        Geometry oldGeometry = this.geometry;
        this.geometry = geometry;
        getPropertyChangeSupport().firePropertyChange(PROP_GEOMETRY, oldGeometry, geometry);
    }
    

    PropertyChangeSupport getPropertyChangeSupport(){
        if (propertyChangeSupport == null){
            propertyChangeSupport = new PropertyChangeSupport(this);
        }
        return propertyChangeSupport;
    }
    
    /**
     * Add PropertyChangeListener.
     *
     * @param listener
     */
    @Override
    public void addPropertyChangeListener(PropertyChangeListener listener) {
        assert listener != null;
        getPropertyChangeSupport().addPropertyChangeListener(listener);
    }

    /**
     * Remove PropertyChangeListener.
     *
     * @param listener
     */
    @Override
    public void removePropertyChangeListener(PropertyChangeListener listener) {
        getPropertyChangeSupport().removePropertyChangeListener(listener);
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final TreatmentZone other = (TreatmentZone) obj;
        if (!Objects.equals(this.value, other.value)) {
            return false;
        }
        if (!Objects.equals(this.geometry, other.geometry)) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 53 * hash + Objects.hashCode(this.value);
        hash = 53 * hash + Objects.hashCode(this.geometry);
        return hash;
    }
    
    
}
